@@ -1,9 +1,13 @@
-#!/usr/bin/perl
+#!/usr/app/bin/perl
 
 # example for the gimp-perl-server (also called Net-Server)
 
 use Gimp;
 
+sub query {
+   print STDERR "$0: this script is not intended to be run from within the gimp!\n";
+}
+
 sub net {
   # simple benchmark ;)
   
@@ -12,13 +16,13 @@ sub net {
   
   $bg=$img->layer_new(30,20,RGB_IMAGE,"Background",100,NORMAL_MODE);
   
-  $img->add_layer($bg,1);
+  $bg->add_layer(1);
   
   new Gimp::Display($img);
   
   for $i (0..255) {
      Palette->set_background([$i,255-$i,$i]);
-     $img->edit_fill ($bg);
+     $bg->edit_fill;
      Display->displays_flush ();
   }
   
