@@ -1,9 +1,9 @@
-#!/usr/bin/perl
+#!/usr/app/bin/perl
 
 # sent to me by Seth Burgess <sjburges@ou.edu>
 # small changes my Marc Lehmann <pcg@goof.com>
 
-use Gimp qw( :auto );
+use Gimp;
 use Gimp::Fu;
 
 Gimp::set_trace(TRACE_CALL);
